#' Based on gedii_ccs, team level data is extracted as well as some measurement scales
#' are aggregated.
#'
#' write result also as SPSS and MS excel file.
exportFiles = F


#' two different algorithms exist for how teamsize is calculated. If set to "recruited", then
#' the teamsize will reflect the number of team members that have been recruited and which formed
#' the basis for sending out the questionnaires. It is the teamsize as reported by the team members.
#'
#' If set to "bib" it reflects the teamsize minus those likely members that could not contribute
#' to the publication record of the team either because they are junior roles or are too young.
#' The rule is on line 1107 in the build_gediiccs.R script and based upon v_12R (team role):
#' isNonBibRole    = if_else((Age < 29 & v_11 > 2014) | (v_12R == 1 | v_12R == 8), 1, 0))
#' Team members that are younger than 29 years or have joined the team after 2014 and which are either
#' role = Admin, MA.
#tss_type <- "bib"
tss_type <- "recruited"


if (tss_type == "recruited") {
  src_ccs <- gedii_ccs

} else if (tss_type == "bib"){
  src_ccs <- gedii_ccsb

} else {
  stop("Which tss_type? Stopping.")
}



#' Aggregate team level data and copy other team level variables to the
#' new matrix
#'
tld <- src_ccs %>%
  filter(dispcode >=31) %>%
  group_by(v_1) %>%
  transmute(GroupID              = GroupID,
            teamsize             = teamsize,
            teamsize_recruited   = teamsize_recruited,
            teamsize_bib         = teamsize_bib,
            resptotal            = resptotal,
            resprate             = resprate,
            TL_Country           = Country,
            TL_Age               = mean(Age, na.rm = T), #age
            TL_NrRespWomen       = sum(isWoman, na.rm=T),
            TL_NrRespMen         = sum(isMan, na.rm=T),
            TL_PercRespWomen     = 100*(TL_NrRespWomen / (TL_NrRespWomen + TL_NrRespMen)),
            TL_PercRespMen       = 100*(TL_NrRespMen / (TL_NrRespWomen + TL_NrRespMen)),
            TL_RespGenderBalance = 2*min(TL_PercRespWomen,TL_PercRespMen),
            TL_TimeTeam          = mean(v_10, na.rm=T),
            TL_YrsInTeam         = mean(YrsInTeam, na.rm=T),
            TL_NrSeniorRole      = sum(isSeniorRole, na.rm=T),
            TL_PercSeniorRole    = (TL_NrSeniorRole/teamsize)*100,
            TL_NrMARole          = sum(isMARole, na.rm=T),
            TL_PercMARole        = (TL_NrMARole/teamsize)*100,
            TL_NrPhDRole         = sum(isPhDRole, na.rm=T),
            TL_PercPhDRole       = (TL_NrPhDRole/teamsize)*100,
            TL_NrAdminRole       = sum(isAdminRole, na.rm=T),
            TL_PercAdminRole     = (TL_NrAdminRole/teamsize)*100,
            TL_NrPostdocRole     = sum(isPostdocRole, na.rm=T),
            TL_PercPostddocRole  = (TL_NrPostdocRole/teamsize)*100,
            TL_NrAssistantRole   = sum(isAssistantRole, na.rm=T),
            TL_PercAssistantRole = (TL_NrAssistantRole/teamsize)*100,
            TL_NrJuniorRole      = sum(isJuniorRole, na.rm=T),
            TL_PercJuniorRole    = (TL_NrJuniorRole / teamsize) * 100,
            TL_NrNonBibRole      = sum(isNonBibRole, na.rm=T),
            TL_PercNonBibRole    = (TL_NrNonBibRole / teamsize)*100,
            TL_NrWomenNonBibRole = TL_NrWomenNonBibRole,
            TL_NrMenNonBibRole   = TL_NrMenNonBibRole,
            TL_NrSeniorBib       = NrSeniorBib, #has been updated on November 2018 (see below)!
            TL_PercSeniorBib     = (TL_NrSeniorBib/teamsize)*100,
            TL_NrSeniorExp       = sum(isSeniorExp, na.rm=T),
            TL_PercSeniorExp     = (TL_NrSeniorExp/teamsize)*100,
            TL_Experience        = mean(v_83, na.rm=T), #how many years of experience
            TL_FrqCom            = mean(FrqCom, na.rm=T),
            TL_PInfluMean        = mean(PInflu, na.rm=T),
            TL_PInfluDisp        = sd(PInflu, na.rm=T) / mean(PInflu, na.rm=T), #see Harris & KLein 2007
            TL_DisciplinHQVar    = (1 - sum(prop.table(table(v_5R))^2)), #blau index (variety)
            TL_Tclimate          = mean(Tclimate, na.rm=T),
            TL_TcliVision        = mean(TcliVision, na.rm=T),
            TL_TcliSafety        = mean(TcliSafety, na.rm=T),
            TL_TcliTask          = mean(TcliTask, na.rm=T),
            TL_TcliInno          = mean(TcliInno, na.rm=T),
            TL_Leadstyle         = mean(Leadstyle, na.rm=T),
            TL_LeadIM            = mean(LeadIM, na.rm=T),
            TL_LeadIC            = mean(LeadIC, na.rm=T),
            TL_LeadIS            = mean(LeadIS, na.rm=T),
            TL_LeadII            = mean(LeadII, na.rm=T),
            TL_LeadRExpect       = mean(v_178, na.rm=T), #realistic expections of outcome
            TL_LeadRTime         = mean(v_179, na.rm=T), #realistic notions of time required
            TL_LeadTrust         = mean(v_180, na.rm=T), #fosters trust
            TL_Wclimate          = mean(Wclimate, na.rm=T),
            TL_NrMentors         = sum(v_63R, na.rm=T),
            TL_PercMentors       = (TL_NrMentors/teamsize)*100,
            TL_NrPermContract    = sum(hasPerm, na.rm=T),
            TL_PercPermContract  = (TL_NrPermContract/teamsize)*100,
            TL_NrTempContract    = sum(hasTemp, na.rm=T),
            TL_PercTempContract  = (TL_NrTempContract/teamsize)*100,
            TL_TimeContracted    = mean(v_81, na.rm=T),
            TL_TimeWorking       = mean(v_82, na.rm=T),
            TL_DiffConWork       = TL_TimeWorking - TL_TimeContracted,
            TL_TimePub           = mean(v_85R, na.rm=T),
            TL_Gstereo           = mean(Gstereo, na.rm=T),
            TL_QuesPub           = mean(v_130, na.rm=T),
            TL_QuesPat           = mean(v_131, na.rm=T),
            TL_Fund              = mean(v_84, na.rm=T),
            TL_Ethnic            = sum(v_100R, na.rm=T),
            TL_PercEthnic        = (TL_Ethnic/teamsize)*100,
            TL_Disability        = sum(v_101R, na.rm=T),
            TL_PercDisability    = (TL_Disability/teamsize)*100,
            TL_CareRespPresent   = sum(CareRespPresent, na.rm=T),
            TL_CareRespPast      = sum(CareRespPast, na.rm=T),
            TL_CareResp          = sum(CareResp, na.rm=T),
            TL_PercCareResp      = (TL_CareResp/teamsize)*100,
            TL_CareDoesAffect    = sum(CareDoesAffect, na.rm=T),
            TL_PercCareDoesAffect= (TL_CareDoesAffect/teamsize)*100,
            TC_OrgType           = TC_OrgType,
            TC_NumEmployees      = TC_NumEmployees,
            TC_FoundingYear      = TC_FoundingYear,
            TC_Colocation        = TC_Colocation,
            TC_GEP               = TC_GEP,
            TC_GenderDim         = TC_GenderDim,
            TC_NrWomen           = TC_NrWomen,
            TC_NrMen             = TC_NrMen,
            TC_PercWomen         = 100*(TC_NrWomen / ( TC_NrWomen + TC_NrMen)),
            TC_PercMen           = 100*(TC_NrMen / ( TC_NrWomen + TC_NrMen)),
            TC_GenderBalance     = 2*min( TC_PercWomen, TC_PercMen),
            FAP1000              = FAP1000,
            PMM1000              = PMM1000,
            InternatCollab       = InternatCollab,
            OutwardTotal         = OutwardTotal,
            Index.6                     = Index.6,
            Seniority_attrition         = Leader_attrition,       #added Jan 2019 GDI Pillars
            Seniority_blauH             = Leader_blauH,
            Seniority_score             = pillar_leadership_score,
            Tenure_attrition            = Tenure_attrition,
            Tenure_blauH                = Tenure_blauH,
            Tenure_score                = pillar_tenure_score,
            CareCurrent_attrition       = CareCurrent_attrition,
            CareCurrent_blauH           = CareCurrent_blau,
            CareCurrent_score           = pillar_care_score,
            Contract_attrition          = Contract_attrition,
            Contract_blauH              = Contract_blauH,
            Contract_score              = pillar_contract_score,
            Education_attrition         = Education_attrition,
            Education_blauH             = Education_blauH,
            Education_score             = pillar_education_score,
            Marital_attrition           = Marital_attrition,
            Marital_blauH               = Partner_blau,
            Marital_score               = pillar_marital_score,
            AgeAv_attrition             = AgeAv_attrition,
            AgeAv_blauH                 = AgeAv_blauH,
            AgeAv_score                 = pillar_age_score,
            FAP8Y1000_Nov18             = FAP8Y1000_Nov18,        #added corrected November 2018
            PMM8Y1000_Nov18             = PMM8Y1000_Nov18,
            FAP5Y_Nov18                 = FAP5Y_Nov18,
            PMM5Y_Nov18                 = PMM5Y_Nov18,
            PMM5Y1000_Nov18             = PMM5Y1000_Nov18,
            FAP5Y1000_Nov18             = FAP5Y1000_Nov18,
            FAP5Y1000xNrSeniorBib_Nov18 = FAP5Y1000xNrSeniorBib_Nov18,
            PMM5Y1000xNrSeniorBib_Nov18 = PMM5Y1000xNrSeniorBib_Nov18,
            TeamType_Nov18              = TeamType_Nov18,
            ColocationBib_Nov18         = ColocationBib_Nov18,
            Inward_Nov18                = Inward_Nov18,
            InwardNorm_Nov18            = InwardNorm_Nov18,
            InwardNormMedian_Jan19      = InwardNormMedian_Jan19,
            OrgTypeR_Nov18              = OrgTypeR_Nov18,
            Field_Nov18                 = Field_Nov18,
            Applied_Nov18               = Applied_Nov18,
            CountryBib_Nov18            = CountryBib_Nov18,
            SubjectFieldDiv_Nov18       = SubjectFieldDiv_Nov18,
            TL_NrSeniorBib_Nov18        = NrSeniorBib_Nov18,
            TL_PercSeniorBib_Nov18      = (NrSeniorBib_Nov18/teamsize)*100) %>%
  distinct()


#' UPDATE 12 NOVEMBER 2018
#' read and join gender based on name assignment
#' Member names have been revised and gender assigned manually based on first name
#'
df.g <- read_gpg("data-raw/df.gender_assigned.xlsx.gpg")


#' correct team codes in order to match existing ones in the data set
df.g[which(df.g$v_1 == "W115T1507U"), "v_1"] <- "WT115T1507U"
df.g[which(df.g$v_1 == "Z116T1628U"), "v_1"] <- "ZT116T1628U"
df.g[which(df.g$v_1 == "OT104T1253U"),"v_1"] <- "CT104T1253U"

tmp <- select(tld, TL_NrWomenNonBibRole, TL_NrMenNonBibRole, v_1)

df.g %<>%
  left_join(tmp, by="v_1")


#' depending on which dataset is constructed "recruitment" or "bib", we manually
#' remove the number of women/men from the non-bib-team
df.g %<>%
  filter(v_1 != "Case Study") %>%
  mutate(IsWoman = if_else(gender == "f", 1, 0),
         IsMan = if_else(gender == "m", 1, 0)) %>%
  group_by(v_1) %>%
  summarize(TL_NrWomen       = sum(IsWoman, na.rm=T),
            TL_NrMen         = sum(IsMan, na.rm=T),
            TL_NrWomen       = if_else(tss_type == "bib", (TL_NrWomen - TL_NrWomenNonBibRole[1]), TL_NrWomen),
            TL_NrMen         = if_else(tss_type == "bib", (TL_NrMen - TL_NrMenNonBibRole[1]), TL_NrMen),
            TL_PercWomen     = 100*(TL_NrWomen / (TL_NrWomen + TL_NrMen)),
            TL_PercMen       = 100*(TL_NrMen / (TL_NrWomen + TL_NrMen)),
            TL_GenderBalance = 2*min(TL_PercWomen,TL_PercMen))

tld %<>%
  left_join(df.g, by="v_1")


rm(df.g)

#' UPDATE 28 NOVEMBER 2018
#'
#' Gender of seniors (bib) and team leader has been manually assigned and is available
#'
df.g <- read_gpg("data-raw/df.GEDII_SeniorBIB_28NOV2018.xlsx.gpg")

#' gender of seniors
df.gsb <- df.g %>%
  filter(isSenior == 1) %>%
  mutate(GroupNumber = Group,
         IsWomenSeniorBib         = if_else(gender == "woman", 1, 0),
         IsManSeniorBib           = if_else(gender == "man", 1, 0)) %>%
  group_by(GroupNumber) %>%
  summarize(TL_NrWomenSeniorBib   = sum(IsWomenSeniorBib, na.rm=T),
            TL_NrMenSeniorBib     = sum(IsManSeniorBib, na.rm=T),
            TL_PercWomenSeniorBib = 100*(TL_NrWomenSeniorBib / (TL_NrMenSeniorBib + TL_NrWomenSeniorBib)),
            TL_PercMenSeniorBib   = 100*(TL_NrMenSeniorBib /(TL_NrMenSeniorBib + TL_NrWomenSeniorBib)),
            TL_GenderBalanceSeniorBib = 2*min(TL_PercWomenSeniorBib,TL_PercMenSeniorBib))

tld %<>%
  left_join(df.gsb, by="GroupNumber")


#' add bibliometric team numbers and gender data
df.bib <- df.g %>%
  filter(!is.na(Name)) %>%
  rename(GroupNumber = Group) %>%
  group_by(GroupNumber) %>%
  transmute(TL_NrBib         = n(),
            IsWomanBib       = if_else(gender == "woman", 1, 0),
            IsManBib         = if_else(gender == "man", 1, 0),
            TL_NrWomenBib    = sum(IsWomanBib, na.rm=T),
            TL_NrMenBib      = sum(IsManBib, na.rm=T),
            TL_PercWomenBib  = (TL_NrWomenBib / TL_NrBib)*100,
            TL_PercMenBib    = (TL_NrMenBib / TL_NrBib)*100,
            TL_GenderBalanceBib = 2*min(TL_PercWomenBib,TL_PercMenBib)) %>%
  select(-IsWomanBib, -IsManBib) %>%
  distinct()

tld %<>%
  left_join(df.bib, by="GroupNumber")

tld %<>%
  mutate(TL_PercBib = (TL_NrBib / teamsize)*100)



#' gender of team leader
df.gtl <- df.g %>%
  filter(!is.na(Name) & leader == 1) %>%
  transmute(GroupNumber = Group,
            TL_GenderLeader = gender)

tld %<>%
  left_join(df.gtl, by="GroupNumber")

#' remove v_1 group id.
tld %<>%
  select(-v_1)

if (tss_type == "recruited"){

  #' rename
  gedii_tld <- tld
  save(gedii_tld, file = "data/gedii_tld.rdata")

  message("\nRecruited teamsize dataset build and saved to gedii_tld.rdata")

} else if (tss_type == "bib"){

  #correct TL_PercBib > 100%
  tld[which(tld$GroupNumber == 18), "TL_PercBib"] <- 100

  gedii_tldb <- tld
  save(gedii_tldb, file = "data/gedii_tldb.rdata")

  message("\nBib-teamsize dataset build and saved to gedii_tldb.rdata")

}


