% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gedii_ccs.R
\name{gedii_ccs}
\alias{gedii_ccs}
\title{GEDII Individual Level Data (cross-country survey)}
\description{
Documentation for the result matrix of the GEDII cross country survey on the individual respondent level. Although
the documentation is included in `gediiccs`, the actual individual responses dataset does not form part of this
package.\cr\cr \strong{In order to safeguard the anonymity of respondents, the open access version contains the
aggregated team level data \link{gedii_tld} only}.\cr\cr
}
\section{Metadata (Team Member)}{


\cr\strong{\code{rowid} - Unique identifier of response}

Letters mark source survey "a": personalized, "b" anonymous, "c" institute.
See also \code{external_lfdn} which is survey specific counter of submissions, each starting at 1.


\cr\strong{\code{dispcode} - Unipark response codes}

\tabular{cl}{
 22 - \tab "Suspended" - Check \code{lastpage}. \cr
 31 - \tab "Completed"\cr
 32 - \tab "Completed after break"\cr
}


\cr\strong{\code{tester} - Entries by person testing the survey}

All entries are "0". Testers have been removed during preprocessing.


\cr\strong{\code{lastpage} - Last visited page by respondent}

Codes last visited page by respondent.


\cr\strong{\code{duration} - Time to complete survey}

How long did respondent take to finish questionnaire. In case of \code{dispcode=32}, i.e. responding
with break, the number does not make sense.


\cr\strong{\code{quality} - Unipark calculations of quality of submission}

Ignored.

\cr\cr
}

\section{Team Member Survey}{



\cr\strong{\code{v_1} - Team Code}

Unique team identifier for each recruited team, indicating country, sector and unique timestamp.
Removed from open access dataset.


\cr\strong{\code{GroupNumber}}

ID of groups for which bibliometric profile and GDI has been calculated. Total 101 groups.
Removed from open access dataset.


\cr\strong{\code{GroupID}}

Anonymized ID of each group based upon md5 of \code{v_1}. Only group ID used in open access dataset.



\cr\strong{\code{teamsize}}

For this dataset, the teamsize indicates the total number of recruited team members, including
the team leader. It is the size of the target population of each group.


\cr\strong{\code{teamsize_recruited}}

Same as \code{teamsize} for this dataset.


\cr\strong{\code{teamsize_bib}}

Indicates the team size after removing all members that are likely to have not contributed to the
bibliometric record of the group. \code{teamsize_bib = teamsize_recruited - NrNonBibRole}


\cr\strong{\code{resptotal} - Number of responses from team}

See also \code{resprate} - resptotal/teamsize.


\cr\strong{\code{Country} - Country of residence of team}


\cr\strong{\code{v_4} - Which is your highest level of education?}

See also: \code{v_4R} recodified; \code{v_222} Content of "Other"
\tabular{cl}{
 1 - \tab "Secondary education"\cr
 2 - \tab "Bachelor"\cr
 3 - \tab "Master or equivalent postgraduate qualification"\cr
 4 - \tab "Doctorate or higher"\cr
 5 - \tab "Other, please specify:"\cr
}


\cr\strong{\code{v_5} - In which discipline did you obtain your highest qualification?}

See also: \code{v_5R} \code{v_5STEM}, \code{v_223} Content "Other"
\tabular{cl}{
 1 - \tab "Chemistry, Physics & Engineering"\cr
 2 - \tab "Life Science & Medical Science"\cr
 3 - \tab "Sociology, Economics & Political Science"\cr
 4 - \tab "Computer Science & Mathematics"\cr
 5 - \tab "Psychology & Education" \cr
 6 - \tab "Agriculture & Food Science"\cr
 7 - \tab "Biology, Environmental Science & Geography"\cr
 8 - \tab "Humanities"\cr
 9 - \tab "Other, please specify:"\cr
}


\cr\strong{\code{v_6} - Year of birth.}

See also: \code{Age} has been calculated with reference year 2017.


\cr\strong{\code{v_7} I am (gender)}

See also: \code{v_7R} "Other" recodified, and \code{isWoman, isMan} logical (for easy counting/aggregating).
\tabular{cl}{
 1 - \tab "A woman"\cr
 2 - \tab "A man"\cr
 3 - \tab "Other"\cr
}

\cr\cr
}

\section{You and your team}{


\cr\strong{\code{v_10} How much of your work time do you dedicate to your team?}
\tabular{cl}{
 1 - \tab "< 20\%"\cr
 2 - \tab "20 - 39\%"\cr
 3 - \tab "40 - 59\%"\cr
 4 - \tab "60 - 79\%"\cr
 5 - \tab "80 - 100\%"\cr
}


\cr\strong{\code{v_11} - In which year did you join your team?}

See also: \code{YrsInTeam} - reference year 2017

Team tenure.


\cr\strong{\code{v_12} - Which of the following best describes your primary, current role in the team?}

See also: \code{v_12R} "Other" recodified; \code{v_18} Text content of "Other". Recode \code{v_12} to
\code{isSeniorRole} if v_12R==5 or 6, i.e. if respondent is "Senior researcher" or "Team leader".
Other related variables \code{v_83} (years of experience in the field),
\code{NrSeniorBib} (bibliometric seniority), and \code{SeniorExp} (experience based seniority).

\tabular{cl}{
 1 - \tab "MA Student"\cr
 2 - \tab "PhD Student"\cr
 3 - \tab "Research or lab assistant / technician"\cr
 4 - \tab "Postdoc / Junior researcher"\cr
 5 - \tab "Senior researcher"\cr
 6 - \tab "Team leader"\cr
 7 - \tab "Other, please specify:"\cr
 8 - \tab "Administration"\cr
}


\cr\strong{\code{v_13-v17} - How often and by which means do you normally communicate with your team colleagues?}


\tabular{cl}{
 \strong{\code{v_13}} \tab Formal project team meetings with the majority of team members\cr
 \strong{\code{v_14}} \tab Memos or written reports of any kind\cr
 \strong{\code{v_15}} \tab Making an appointment with one or several team member(s)\cr
 \strong{\code{v_16}} \tab Telephone, skype calls, chats, email\cr
 \strong{\code{v_17}} \tab Informal or unplanned discussion (e.g. just stopping by, in the hall, over coffee
}

Options:
\tabular{cl}{
 1 - \tab "Never"\cr
 2 - \tab "Once per month or less"\cr
 3 - \tab "Once per week or less" \cr
 4 - \tab "A few times per week" \cr
 5 - \tab "Once per day or more"\cr
}



\cr\strong{\code{v_143-145} To which extent do you think that you can influence your team members?}

See also \code{PInflu} which holds mean over variables \code{v_143-v_145}.

\tabular{cl}{
 \strong{\code{v_143}} \tab I have preferential position in my team and I can easily influence the other team members\cr
 \strong{\code{v_144}} \tab I have the resources and power to influence the actions of the other team members\cr
 \strong{\code{v_145}} \tab I have more power within my team compared to the other team members.\cr
}

Options:
\tabular{cl}{
 1 - \tab "Strongly disagree"\cr
 2 - \tab "Disagree"\cr
 3 - \tab "Undecided" \cr
 4 - \tab "Agree" \cr
 5 - \tab "Strongly agree"\cr
}



\cr\strong{\code{v_151-164} How would you characterise the working climate within your team? }

See also \code{Tclimate} which holds row mean over \code{v_151-v_164} variables.

These items are based upon short team climate scale, which comprises ideally four different dimensions:

\itemize{
 \item Vision: \code{TcliVision} row mean including \code{v_151, v_152, v_153, v_154, v_155}
 \item Participant safety: \code{TcliSafety} row mean including \code{v_156, v_157, v_158}
 \item Task orientation: \code{TcliTask} row mean including \code{v_159, v_160, v_161}
 \item Support for innovation: \code{TcliInno} row mean including \code{v_162, v_163, v_164}
}

\tabular{cl}{
 \strong{\code{v_151}} \tab I am clear about what my team's objectives are\cr
 \strong{\code{v_152}} \tab I am in agreement with the team's objectives\cr
 \strong{\code{v_153}} \tab The team's objectives are clearly understood by other members of the team\cr
 \strong{\code{v_154}} \tab The team's objectives can actually be achieved\cr
 \strong{\code{v_155}} \tab The team's objectives are worthwhile to the organisation\cr
 \strong{\code{v_156}} \tab We keep each other informed about work-related issues in the team\cr
 \strong{\code{v_157}} \tab There are real attempts to share information throughout the team\cr
 \strong{\code{v_158}} \tab We have a 'we are in it together' attitude\cr
 \strong{\code{v_159}} \tab We are prepared to question the basis of what the team is doing\cr
 \strong{\code{v_160}} \tab We critically appraise potential weaknesses in what we are doing in order to achieve the best possible outcome\cr
 \strong{\code{v_161}} \tab We build on each other's ideas in order to achieve the best possible outcome\cr
 \strong{\code{v_162}} \tab We are always searching for fresh, new ways of looking at problems\cr
 \strong{\code{v_163}} \tab We take the time needed to develop new ideas\cr
 \strong{\code{v_164}} \tab We co-operate in order to help each other and apply new ideas\cr
}

Options:
\tabular{cl}{
 1 - \tab "Strongly disagree"\cr
 2 - \tab "Disagree"\cr
 3 - \tab "Undecided" \cr
 4 - \tab "Agree" \cr
 5 - \tab "Strongly agree"\cr
}



\cr\strong{\code{v_170-180} - Please assess your team leaders’ leadership style.}

See also \code{Leadstyle} which holds row means over \code{v_170-v_177}.

The team leadership scale ideally produces a four factor structure:

\itemize{
 \item Inspirational motivation: \code{LeadIM} row mean including \code{v_170, v_171}
 \item Individualized consideration: \code{LeadIC} row mean including \code{v_172, v_173}
 \item Intellectual stimulus: \code{TLeadIS} row mean including \code{v_174, v_175}
 \item Idealized influence: \code{LeadII} row mean including \code{v_176, v_177}
}

\tabular{cl}{
 \strong{\code{v_170}} \tab She/he develops ways of motivating us\cr
 \strong{\code{v_171}} \tab I feel proud to work with her/him\cr
 \strong{\code{v_172}} \tab I have trust in her/his ability to overcome any obstacle\cr
 \strong{\code{v_173}} \tab She/he is concerned with training those who need it\cr
 \strong{\code{v_174}} \tab She/he gives advice to those who need it\cr
 \strong{\code{v_175}} \tab She/he gets us to rely on reasoning and evidence to solve problems\cr
 \strong{\code{v_176}} \tab She/he promotes the use of intelligence to overcome obstacles\cr
 \strong{\code{v_177}} \tab She/he presents things through an approach that stimulates me\cr
}

NOTE: Additional items in this question block are the following three, although they do \emph{not} form part
of the original team leadeship scale.

\tabular{cl}{
 \strong{\code{v_178}} \tab She/he has realistic expectations on the outcome of my work\cr
 \strong{\code{v_179}} \tab She/he has realistic expectations on the time schedule I need for my work\cr
 \strong{\code{v_180}} \tab She/he actively fosters trust, involvement and cooperation among team members\cr
}

Options:
\tabular{cl}{
 1 - \tab "Strongly disagree"\cr
 2 - \tab "Disagree"\cr
 3 - \tab "Undecided" \cr
 4 - \tab "Agree" \cr
 5 - \tab "Strongly agree"\cr
}



\cr\strong{\code{v_186-189} - How would you characterise the working climate at your wider working environment?}

See also \code{Wclimate} which holds mean value over variables \code{v_186-v_189}.

\tabular{cl}{
 \strong{\code{v_186}} \tab Senior employees respect junior male and female employees equally\cr
 \strong{\code{v_187}} \tab In meetings, people pay just as much attention when women speak as when men speak\cr
 \strong{\code{v_188}} \tab Allegations of gender based and sexual harassment are taken seriously by management\cr
 \strong{\code{v_189}} \tab In this organisation, I would feel comfortable to raise issues about the treatment of women or men\cr
}

Options:
\tabular{cl}{
 1 - \tab "Strongly disagree"\cr
 2 - \tab "Disagree"\cr
 3 - \tab "Undecided" \cr
 4 - \tab "Agree" \cr
 5 - \tab "Strongly agree"\cr
}



\cr\strong{\code{v_63} - Is there any senior member within your team whom you currently regard as a mentor—someone who gives advice and counsel on career issues and/or sponsors or advocates for you?}

See also \code{v_63R} recoded where "yes" is 1 and "no" 0!

Options:
\tabular{cl}{
 1 - \tab "Yes"\cr
 2 - \tab "No"\cr
}


\cr\strong{\code{v_64} - My mentor is (gender)}

Options:
\tabular{cl}{
 1 - \tab "A man"\cr
 2 - \tab "A woman"\cr
}


\cr\strong{\code{v_70-79} - Please indicate the level of mentoring you currently receive by your mentor. Select all that apply.}

See also \code{v_71} contains "Other" text.

\tabular{cl}{
 \strong{\code{v_70}} \tab Other, please specify\cr
 \strong{\code{v_72}} \tab Serves as a role model\cr
 \strong{\code{v_73}} \tab Gives advice on my research directions\cr
 \strong{\code{v_74}} \tab Introduces me to his/her professional networks\cr
 \strong{\code{v_75}} \tab Advises about preparation for advancement (e.g. promotion, leadership position) \cr
 \strong{\code{v_76}} \tab Informs me about laboratory / institute / organisational politics\cr
 \strong{\code{v_77}} \tab Helps to obtain resources (funding, grants, etc.) that I need\cr
 \strong{\code{v_78}} \tab Acts as an advocate for me\cr
 \strong{\code{v_79}} \tab Provides advice on work-life balance\cr
}

Options: checkbox (0 - not quoted, 1 - quoted)

\cr\cr
}

\section{Professional situation and career}{


\cr\strong{\code{v_80} - What type of contract do you have?}

See also \code{hasTemp, hasPerm} set to "1" if true and "0" otherwise.

\tabular{cl}{
 1 - \tab "Temporary / casual"\cr
 2 - \tab "Permanent / tenured"\cr
}



\cr\strong{\code{v_81} - How many hours a week are you contracted for?}

\tabular{cl}{
 1 - \tab "Less than 20 hours/ week (part time)"\cr
 2 - \tab "20 up to 35 hours/week (part time)"\cr
 3 - \tab "More than 35 hours (full time)"\cr
}



\cr\strong{\code{v_82} - How many hours do you actually work per week in this job?}

\tabular{cl}{
 1 - \tab "As many hours as I am contracted for"\cr
 2 - \tab "1-5 hours more than I am contracted for"\cr
 3 - \tab "6-10 hours more than I am contracted for"\cr
 4 - \tab "11 hours or more than I am contracted for"\cr
}



\cr\strong{\code{v_83} - How many years of experience do you have in your research area (including PhD years if applicable)?}

See also \code{SeniorExp} which is \code{v_83} recoded to "0" if v_83<=3 or "1" otherwise. Senior researcher based on
experience.

\tabular{cl}{
 1 - \tab "2 years or less"\cr
 2 - \tab "3-5 years"\cr
 3 - \tab "6-9 years"\cr
 4 - \tab "10-19 years"\cr
 5 - \tab "20-29 years"\cr
 6 - \tab "30 years or more"\cr
}



\cr\strong{\code{v_84} -  How much external funding have you raised as lead researcher since  1st January 2013 for your institution or your person?}

See also: \code{v_208} for GBP and \code{v_209} for SEK

\tabular{cl}{
 1 - \tab "None"\cr
 2 - \tab "less than 9999 EUR"\cr
 3 - \tab "10 000 – 24 999 EUR"\cr
 4 - \tab "25 000 - 49 999 Euro"\cr
 5 - \tab "50 000 - 99 999 Euro"\cr
 6 - \tab "100 000 – 499 999 Euro"\cr
 7 - \tab "more than 500 000 Euro"\cr
}



\cr\strong{\code{v_85} - How much of your weekly working time can you spend on average on activities that are geared towards publications and patents?}

\tabular{cl}{
 1 - \tab "< 20\%"\cr
 2 - \tab "20 - 39\%"\cr
 3 - \tab "40 - 59\%"\cr
 4 - \tab "60 - 79\%"\cr
 5 - \tab "80 - 100\%"\cr
 6 - \tab "Publications/ patents are typically not part of my work"\cr
}



\cr\strong{\code{v_86} - Are you an editor to scientific journals that have an impact factor? If yes, to how many?}

See also \code{v_96} in case of "Yes", indicates quantity.

\tabular{cl}{
 1 - \tab "No"\cr
 2 - \tab "Yes"\cr
}



\cr\strong{\code{v_87} - Are you a member of a management board of a professional or scientific association in your field? If yes, of how many?}

See also \code{v_97} in case of "Yes", indicates quantity.

\tabular{cl}{
 1 - \tab "No"\cr
 2 - \tab "Yes"\cr
}



\cr\strong{\code{v_213, v_215-220} - Did you engage in any of the following dissemination and knowledge transfer activities during the past year? Select all that apply. }

See also \code{v_214} contains text for "Other"

\tabular{cl}{
 \strong{\code{v_213}} \tab Other, please specify\cr
 \strong{\code{v_215}} \tab Workshops and dissemination events for academic audiences\cr
 \strong{\code{v_216}} \tab Workshops and dissemination events for non-academic audiences (e.g. schools, teachers)\cr
 \strong{\code{v_217}} \tab Popular press (Radio, TV, Newspapers or Magazines)\cr
 \strong{\code{v_218}} \tab Social media including blogs for my professional work (on a regular basis)\cr
 \strong{\code{v_219}} \tab Science cafés, science festivals, reseachers' nights\cr
 \strong{\code{v_220}} \tab None of the above\cr
}



\cr\strong{\code{v_199} - Have you “published” under open access schemes? Select all that apply. }

See also \code{v_211} contains text for "Other"

\tabular{cl}{
 \strong{\code{v_199}} \tab Yes, software under Open Source licenses\cr
 \strong{\code{v_200}} \tab Yes, data under open access\cr
 \strong{\code{v_201}} \tab Yes, scientific articles under open access\cr
 \strong{\code{v_210}} \tab Other, please specify:\cr
 \strong{\code{v_221}} \tab None of the above\cr
}



\cr\strong{\code{v_95} - Do you involve citizens in the discussion of the implications of your research?}

\tabular{cl}{
 1 - \tab "On a regular basis"\cr
 2 - \tab "Occasionally"\cr
 3 - \tab "Never"
}

\cr\cr
}

\section{Personal information}{


\cr\strong{\code{v_100} - Do you consider yourself to be a member of a minority ethnic group?}

See also \code{v_100R} recode 1=1, and 2=0.

\tabular{cl}{
 1 - \tab "Yes"\cr
 2 - \tab "No"\cr
}



\cr\strong{\code{v_101} - Do you consider yourself to have a disability or chronic illness?}

See also \code{v_101R} recode 1=1, and 2=0.

\tabular{cl}{
 1 - \tab "Yes"\cr
 2 - \tab "No"\cr
}



\cr\strong{\code{v_102} - Do you live with a partner (marriage, cohabitation, civil partnership, etc)? }

\tabular{cl}{
 1 - \tab "Yes"\cr
 2 - \tab "No"\cr
}



\cr\strong{\code{v_195-198} - Please share with us your opinion on the following statements.}

See also \code{Gstereo} which holds row-wise mean over variables \code{v_195-v_198}.

\tabular{cl}{
 \strong{\code{v_195}} \tab Women and men have their respective strengths in different areas\cr
 \strong{\code{v_196}} \tab Women and men generally have different ways of contributing to a team task\cr
 \strong{\code{v_197}} \tab Women and men generally have different communication styles\cr
 \strong{\code{v_198}} \tab Many of the widespread ideas about how women and men differ are accurate\cr
}

Options:

\tabular{cl}{
 1 - \tab "Strongly disagree"\cr
 2 - \tab "Disagree"\cr
 3 - \tab "Undecided" \cr
 4 - \tab "Agree" \cr
 5 - \tab "Strongly agree"\cr
}



\cr\strong{\code{v_132} - Do you have/ have had care responsibilities for children under 16 years of age or for dependent adults? Select all that apply. }

\tabular{cl}{
 \strong{\code{v_132}} \tab Yes, for children under 16 years\cr
 \strong{\code{v_119}} \tab Yes, in the past for children under 16 years\cr
 \strong{\code{v_120}} \tab Yes, for dependent adults\cr
 \strong{\code{v_121}} \tab Yes, in the past for dependent adults\cr
 \strong{\code{v_122}} \tab No
}



\cr\strong{\code{CareRespPresent} - Has care responsibilities (present)}

Set to 1 if \code{v_132} or \code{v_120} is true.



\cr\strong{\code{CareRespPast} - Had care responsibilities (past)}

Set to 1 if \code{v_119} or \code{v_121} is true.


\cr\strong{\code{CareResp} - Has/had care responsibilities}

Set to 1 if \code{v_119} or \code{v_121} or \code{v_132} or \code{v_120} is true.



\cr\strong{\code{v_123} - To which extent do/did these care responsibilities affect your work?}

\tabular{cl}{
 1 - \tab "Not at all"\cr
 2 - \tab "To some extent"\cr
 3 - \tab "To a large extent"
}



\cr\strong{\code{CareDoesAffect} - Care responsibilities affect work}

True if \code{v_123} == 2 or 3.



\cr\strong{How do/did your care responsibilities affect your work? Select all that apply.}

See also \code{v_136} contains "Other" text

\tabular{cl}{
 \strong{\code{v_124}} \tab Significant reduction of my working hours\cr
 \strong{\code{v_125}} \tab My work schedules got much more fragmented\cr
 \strong{\code{v_126}} \tab Participation in travel related businesses (such as congresses) dropped\cr
 \strong{\code{v_127}} \tab The amount of my scientific papers/ patents dropped\cr
 \strong{\code{v_128}} \tab I quit my job\cr
 \strong{\code{v_129}} \tab Slight reduction of my working hours\cr
 \strong{\code{v_133}} \tab More than 6 months of interruption of my professional career (excluding maternity /paternity/ parental leave)\cr
 \strong{\code{v_134}} \tab Less than 6 months of interruption of my professional career (excluding maternity/ paternity/ parental leave)\cr
 \strong{\code{v_135}} \tab Other, please specify:\cr
 \strong{\code{v_137}} \tab None of the above
}



\cr\strong{\code{v_130} - How many peer reviewed articles have you published since 1st January 2013?}

\tabular{cl}{
 1 - \tab "0"\cr
 2 - \tab "1-4"\cr
 3 - \tab "5 - 9" \cr
 4 - \tab "10 - 19" \cr
 5 - \tab "20 – 39"\cr
 6 - \tab "40 or more"\cr
}



\cr\strong{\code{v_131} - On how many European patents have you been named as an inventor since 1st January 2013 (including pending accepted applications)?}

\tabular{cl}{
 1 - \tab "0"\cr
 2 - \tab "1-4"\cr
 3 - \tab "5 - 9" \cr
 4 - \tab "10 - 19" \cr
 5 - \tab "20 – 39"\cr
 6 - \tab "40 or more"\cr
}


\cr\cr
}

\section{Team Contact Survey}{



\cr\strong{\code{TC_OrgType} - In which type of organisation do you work?}

See also: \code{TC_OrgTypeOther} Text content of "Other"
\tabular{cl}{
 1 - \tab "University"\cr
 2 - \tab "Public research center"\cr
 3 - \tab "Private sector/ industry" \cr
 6 - \tab "Other, please specify" \cr
}



\cr\strong{\code{TC_NumEmployees} - How many employees does your organisation have?}

\tabular{cl}{
 1 - \tab "< 50"\cr
 2 - \tab "50 - 250"\cr
 3 - \tab "250 - 500" \cr
 4 - \tab "500 - 1000" \cr
 5 - \tab "> 1000"\cr
}



\cr\strong{\code{TC_NrWomen, TC_NrMen} - How many women and men are working in your team?}



\cr\strong{\code{TC_Topic} - Can you describe in 1-2 sentences what this team is working on?}


\cr\strong{\code{TC_FoundingYear} - In which year was the current team leader officially appointed as team leader by your organisation?}



\cr\strong{\code{TC_Method} - Does the team employ a particular formal working methodology as part of your research or problem solving (such as Agile methods, TRIZ, Design Thinking, …)?}

See also \code{TC_MethodOther} text content of "Yes"
\tabular{cl}{
 1 - \tab "Yes, please specify"\cr
 2 - \tab "No"\cr
 3 - \tab "I don't know" \cr
}



\cr\strong{\code{TC_Colocation} - Do team members have the opportunity to interact face to face?}

\tabular{cl}{
 1 - \tab "Most team members share the same physical location (lab, office, building) in walking distance to each other"\cr
 2 - \tab "Some team members are within walking distance, others are located further away"\cr
 3 - \tab "Most team members are working in different locations; face-to-face meetings require travel arrangements" \cr
}



\cr\strong{\code{TC_GEP} - Does your organisation have a Gender Equality Plan? }

\tabular{cl}{
 1 - \tab "Yes"\cr
 2 - \tab "No"\cr
 3 - \tab "I don't know" \cr
}



\cr\strong{\code{TC_GenderDim} - Does your research integrate a “gender dimension”?}

See also: \code{TC_GenderDimSpecify} Text content of TC_GenderDim
\tabular{cl}{
 1 - \tab "Yes, please specify"\cr
 2 - \tab "No"\cr
 3 - \tab "I don't know" \cr
}



\cr\strong{Is your team involved in any Responsible Research & Innovation(RII) activities? If so, which?}

\tabular{cl}{
 \strong{\code{TC_RRI_Ethics}} \tab Ethics\cr
 \strong{\code{TC_RRI_Gender}} \tab Gender Equality\cr
 \strong{\code{TC_RRI_Gov}} \tab Governance\cr
 \strong{\code{TC_RRI_OA}} \tab Open Access\cr
 \strong{\code{TC_RRI_Pub}} \tab Public Engagement\cr
 \strong{\code{TC_RRI_SciEdu}} \tab Science Education\cr
 \strong{\code{TC_RRI_DKnow}} \tab I don't know\cr
}

\cr\cr
}

\section{Performance indicators}{


\cr\strong{\code{FAP} - Field Adjusted Productivity}

See also \code{FAP1000} where \code{FAP*1000} values have been multiplied by 1000 to avoid rounding
errors when converting to real counts.

FAP is a measure of research productivity, that is, about how many publications are produced by a
given team. Since productivity varies between disciplines, the indicator normalizes the number
of publications to the average productivity of a senior researcher within a given field. Field
Adjusted Productivity is thus an abstract quantity in the sense that it measures productivity not in
direct publication counts, but via the average number of papers published by a senior researcher.
This might be relatively high for researchers working in engineering disciplines and lower for
seniors working in social sciences or humanities.

The unit of FAP is therefore "average productivity of one senior reseacher". A FAP of 1 means that the
given group has the productivity of one senior researcher in its field. A FAP of 5 means that a given
team produces as many papers as one would expect of a group comprising 5 senior researchers (within
the given field). This is independent of the actual team size and actual number of senior researchers
a given team actually has. A very productive team would be a team of 2, one senior and one PhD with a
FAP score of 4 - meaning they produce as many papers in their field as you would expect from a team made
up of 4 senior researchers.

The FAP scores have been benchmarked according to the average research output of all nordic countries.
Data was collected over a 4 year period, which means a FAP score of 1 reflects the research productivity
of a senior researcher over 4 years. This might be 20 papers for medical scholars and 4 papers for
sociologists, both having a corresponding FAP score of 1.

In the GEDII project, publication data was collected over a period of 8 years. Although we can expect
that this produces up to 40 papers for medical scholars (to stick with the previous example) and
8 papers for sociologist, the resulting FAP score for both is "2". This is to say that the FAP score
is \emph{not} normalized over the time period the corresponding publications were collected. This is
important when interpreting the coefficients of potential regressions: the time period over which
a group gains/looses the productivity of a senior has always to be taken into account.




\cr\strong{\code{PMM} - Percentile Model}

See also \code{PMM1000} where \code{PMM*1000} values have been multiplied by 1000 to avoid rounding
errors when converting percentages to real counts.  And see also: \code{AvgFracTOP1, AvgFracTOP5, AvgFracTOP10, AvgFracTOP25, AvgFracTOP50}

Articles are rated based upon their citations and then assigned to point-categories, such that an article
in the top 1\% = 100 points, top 5\% = 20 points, top 10\% = 10 points, top 25\% = 4 points, top 50\% = 2
points and the rest 1 point. The percentile model is field adjusted. The higher the PM score, the more
likely is that the output of a team belongs to the top research groups within a ield. For instance, if a
team’s publicatons are mainly amongst the top 1% of all cited publicatons within their area of research,
they would achieve one of the highest PM scores, while teams with few citatons would be on the bottom end
of the PM score.



\cr\strong{\code{NrSeniorBib} - Senior researcher bibliometric}

Bibliometric based definition of "seniority". Total number of seniors in team defined as having at least 5 consecutive
publications indexed in Web of Science for the given time period 2011-2016.Total seniors on the team level.



\cr\strong{\code{SeniorExp} - Senior researcher experience}

Based on \code{v_83}.

Experience based definition of "seniority". Value is set to "1" if respondent has \code{v_83 >=4}, i.e. more
than 10 years of experience and set to "0", otherwise.



\cr\strong{\code{OutwardTotal} - ??}



\cr\strong{\code{InternatCollab} - ??}

International Collaboration.



\cr\strong{\code{AvgFracNCSj} - Journal Normalized Citation Score}

The Journal Normalized Citation Score sets the citations of the groups' articles in relation to the
mean citations of all other articles within the same journals.



\cr\strong{\code{AvgFracNJCS} - Normalized Journal Citation Score}

Scientific impact is not only measured by citations but also by the prestige of the journal in which the
research group publishes. The NJCS indicates the impact of the research groups journal set in relation
to all other journals of its scientific sub-field



\cr\strong{\code{AvgNCSf} - Field Normalized Citation Score}

As a final step, the number of citations received by the research groups' articles is set in relation to
the average citation count of articles within their scientific sub-field. a research group that obtains
a NCSf score of 1.01 matches almost exactly the mean of its sub-field and thus performs at international
average level, as good as most other research groups within its area.



\cr\strong{\code{AvgNCSf2y} - Field Normalized Citation Score - 2 years}


\cr\strong{\code{AvgFracAUm} - ??}


\cr\strong{\code{AvgFracIntCOLLm} - ??}


\cr\strong{\code{CountFullBMXID} - ??}


\cr\strong{\code{CountFracBMXID} - ??}



\cr\strong{Index.6 - Gender Diversity Index score}

The Gender Diversity Index score of the team. Seven grounds of diversity are included: age, educational
level, care responsibilites, marital status, type of contract, seniority and team tenure (years of
experience in the team). The Gender Diversity Index is a composite indicator which combines data on those
seven grounds into one fgure. It is bound between 0 and 1, and measures both parity in representaton in
the most desirable categories (e.g. senior roles) or more inclusive categories (e.g. care responsibilites),
as well as equal chances for women and men to access these categories (atriton) for each of the seven
grounds. In other words, women and men should be equally represented in the more desirable or inclusive
categories, and the 'pipeline' there should not be leaking.


\cr\strong{Gender Diversity Index - Individual Pillars}

The scores for the individual pillars that comprise the GDI are included in the dataset: Seniority,
Tenure, CareCurrent, Contract, Education, Marital Status, and Age. Three variables are available for
each pillar: X_attrition, X_blauH, and X_score.

\itemize{
 \item{Seniority_attrition: the attrition score for this pillar}
 \item{Seniority_blauH: the blau index (representation) for this pillar}
 \item{Seniority_score: individual score for this pillar}
 \item{Tenure_attrition: the attrition score for this pillar}
 \item{Tenure_blauH: the blau index (representation) for this pillar}
 \item{Tenure_score: individual score for this pillar}
 \item{CareCurrent_attrition: the attrition score for this pillar}
 \item{CareCurrent_blauH: the blau index (representation) for this pillar}
 \item{CareCurrent_score: individual score for this pillar}
 \item{Contract_attrition: the attrition score for this pillar}
 \item{Contract_blauH: the blau index (representation) for this pillar}
 \item{Contract_score: individual score for this pillar}
 \item{Education_attrition: the attrition score for this pillar}
 \item{Education_blauH: the blau index (representation) for this pillar}
 \item{Education_score: individual score for this pillar}
 \item{Marital_attrition: the attrition score for this pillar}
 \item{Marital_blauH: the blau index (representation) for this pillar}
 \item{Marital_score: individual score for this pillar}
 \item{AgeAv_attrition: the attrition score for this pillar}
 \item{AgeAv_blauH: the blau index (representation) for this pillar}
 \item{AgeAv_score: individual score for this pillar}
}

\cr\cr
}

\section{November 2018 Changes}{


Several changes where introduced during November 2018. This includes a correction of performance data
for several groups as well as variables that have been aggregated or transformed based upon existing
variables. All these data refers to the team level but is included into the ccs dataset as well.

\cr\strong{\code{FAP8Y1000_Nov18} - Field Adjusted Productivity, 8 years}

Productivity score based upon 8 years of retrieval of publications, updated for some groups.


\cr\strong{\code{FAP5Y_Nov18} - Field Adjusted Productivity, 5 years}

Productivity score based upon 5 year retrieval of publications. Years included are 2012-2016.


\cr\strong{\code{FAP5Y1000_Nov18} - Field Adjusted Productivity, 5 years x 1000}

\code{FAP5Y_Nov18} multiplied by 1000.


\cr\strong{\code{FAP5Y1000xNrSeniorBib_Nov18} - FAP divided by NrSeniorsBib}

Productivity \code{FAP5Y1000_Nov18} divided by \code{NrSeniorBib_Nov18}.


\cr\strong{\code{PMM8Y1000_Nov18} - Percentile Model, 8 years}

Percentile Model score based upon 8 years of retrieval of publications, updated for some groups.


\cr\strong{\code{PMM5Y_Nov18} - Percentile Model, 5 years}

Percentile model based upon 5 years of retrievel of publications. Years included are 2012-2016.


\cr\strong{\code{PMM5Y1000_Nov18 } - Percentile Model, 5 years}

Percentile Model \code{PMM5Y_Nov18 } multiplied by 1000.


\cr\strong{\code{PMM5Y1000xNrSeniorBib_Nov18} - Percentile Model divided NrSeniorsBib}

Percentile Model \code{PMM1000_Nov18} divided by \code{NrSeniorBib_Nov18}.


\cr\strong{\code{TeamType_Nov18} - Team type}

Recoded variable \code{NrSeniorBib}:

\tabular{cl}{
 1 - \tab "NrSeniorBib == 1"\cr
 2 - \tab "NrSeniorBib >= 2 and NrSeniorBib <= 4"\cr
 3 - \tab "NrSeniorBib > 5" \cr
}


\cr\strong{\code{ColocationBib_Nov18} - Colocation based on bibliometrics}

Bibliometrics based colocation. All authors have same address or not. See also \code{TC_Colocation}
which is based upon questionnaire Team Contact information.

\tabular{cl}{
 1 - \tab "Authors have same address; colocated"\cr
 2 - \tab "Authors have different addresses; distributed"\cr
}


\cr\strong{\code{Inward_Nov18} - Co-author pattern}

Percentage of fractions from the group authors in relation to fractions from co-authors outside the group.

\cr\strong{\code{InwardAvgRef_Nov18} - Inward field referene values}

Average reference values of inward co-author pattern. Reference values exist per field: Applied, EcoSoc,
Health, Natural.


\cr\strong{\code{InwardNorm_Nov18} - Co-author pattern (field normalized)}

Normalized mean "Inward" score based upon field specific factors.


\cr\strong{\code{InwardNormMedian_Jan19} - Co-author pattern (field normalized)}

Normalized median "Inward" score based upon field specific factors


\cr\strong{\code{OrgTypeR_Nov18} - Organisation type}

Recoded organisation type. See also \code{TC_OrgType}

\tabular{cl}{
 1 - \tab "University. TC_OrgType == 1"\cr
 2 - \tab "RPO. TC_OrgType == 2"\cr
 3 - \tab "Other. TC_OrgType == 3 | 6" \cr
}


\cr\strong{\code{NrSeniorBib_Nov18} - Number of Seniors (Bibliometrics)}

Updated number of seniors derived from bibliometrics.


\cr\strong{\code{Field_Nov18} - Scientific fields}

Based upon bibliometric analysis.

\tabular{cl}{
 1 - \tab "Applied"\cr
 2 - \tab "EcSoc"\cr
 3 - \tab "Health" \cr
 4 - \tab "Natural" \cr
}


\cr\strong{\code{Applied_Nov18} - Applied vs. Basic Research}

Based on bibliometric data, most frequent value in the bibliometrics per group, all groups have
several macro-fields but the applied is the largest. ?? \emph{still not clear what entries mean.}

\cr\strong{\code{CountryBib_Nov18} - ??}

National code is based on performance of country in relation to EU average (bibliometrics).
Based on country performance in EC 2013 Research and Innovation Performance in EU member states.
?? \emph{still not clear what entries mean.}

\cr\strong{\code{SubjectFieldDiv_Nov18} - ??}
}

