% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gedii_tld.R
\docType{data}
\name{gedii_tld}
\alias{gedii_tld}
\title{GEDII Team Level Data (cross-country survey)}
\format{A dataframe containing 61 variables. For details of how data has been aggregated on the team level
please see \code{data-raw/build_tld.R}.

\cr\cr}
\usage{
data("gedii_tld")
}
\description{
Result matrix of the GEDII cross country survey, including performance data and Gender Diversity Index.
Overall 159 groups participated, submitting a total of 1501 questionnaires, out of which 1357 are complete.
\cr\cr This result matrix holds the \strong{aggregated data on the team level}. For the individual level
documentation, please see \link{gedii_ccs}. \cr\cr November 2018 an updated version of
the performance scores was produced as well as newly aggregated variables. These variables are all
postfixed with "_Nov18" and documented at the end of this page.
}
\section{Team Member Survey}{



\cr\strong{\code{v_1} - Team Code}

Unique team identifier for each recruited team, indicating country, sector and unique timestamp.
Removed from open access dataset.


\cr\strong{\code{GroupNumber}}

ID of groups for which bibliometric profile and GDI has been calculated. Total 101 groups.
Removed from open access dataset.


\cr\strong{\code{GroupID}}

Anonymized ID of each group based upon md5 of \code{v_1}. Only group ID used in open access dataset.



\cr\strong{\code{teamsize}}

Number of team members including team leader. The complete team member list has been compiled during
the recruitment process.


\cr\strong{\code{resptotal} - Number of responses from team}

See also \code{resprate} - resptotal/teamize.


\cr\strong{\code{TL_Country} - Country of residence of team}

\cr\strong{\code{TL_Age}} -  Mean age across all team respondents.

\cr\strong{\code{TL_NrRespWomen}} - Number of women respondents (based on \code{v_7R})

\cr\strong{\code{TL_NrRespMen}} - Number of men respondents (based on \code{v_7R})

\cr\strong{\code{TL_PercRespWomen}} - Percentage of women (0-100) respondents (not all team members!)

\cr\strong{\code{TL_PercRespMen}} - Percentage of men (0-100) respondents (not all team members!)

\cr\strong{\code{TL_RespGenderBalance}} - Gender balance of respondents

\cr\strong{\code{TL_NrWomen}} - Number of women based upon first name gender assignment for entire
 team, based upon team member listing.

\cr\strong{\code{TL_NrMen}} - Number of men based upon first name gender assignment for entire
 team, based upon team member listing.

\cr\strong{\code{TL_PercWomen}} - Percentage of women in team based upon first name gender assignment,
 based upon team member listing.

\cr\strong{\code{TL_PercMen}} - Percentage of men in team based upon first name gender assignment,
 based upon team member listing.

\cr\strong{\code{TL_GenderBalance}} - Gender balance based upon first name gender assignment,
 based upon team member listing.

\cr\strong{\code{TL_NrWomenSeniorBib}} - Number of women among seniors (based upon bibliometrics). First
  name based gender assignment.

\cr\strong{\code{TL_NrMenSeniorBib}} - Number of men among seniors (based on bibliometrics).  First
  name based gender assignment.

\cr\strong{\code{TL_PercWomenSeniorBib}} - Percentage of women among all seniors (based on bibliometrics). First
  name based gender assignment.

\cr\strong{\code{TL_PercMenSeniorBib}} - Percentage of men among all seniors (based on bibliometrics).  First
  name based gender assignment.

\cr\strong{\code{TL_GenderBalanceSeniorBib}} - Gender balance of all seniors (based on bibliometrics).  First
  name based gender assignment.

\cr\strong{\code{TL_NrBib}} - Number of team members contributing to publications based upon
 bibliometrics.  This is different from SeniorBib since it includes all team members with
 publications, independent of how many.

\cr\strong{\code{TL_PercBib}} - Percentage (0-100) of team members contributing to publications
 based upon bibliometrics. Calculated as TL_NrBib / teamsize.

\cr\strong{\code{TL_NrWomenBib}} - Number of women contributing to publications (based on
 bibliometrics).

\cr\strong{\code{TL_NrMenBib}} - Number of men contributing to publications (based on bibliometrics).

\cr\strong{\code{TL_PercWomenBib}} - Percentage of women (0-100) contributing to publications.

\cr\strong{\code{TL_PercMenBib}} - Percentage of men (0-100) contributing to publications.

\cr\strong{\code{TL_GenderBalanceBib}} - Gender balance among contributing team members to publications.

\cr\strong{\code{TL_GenderLeader}} - Gender of team leader. First name based assignment.

\cr\strong{\code{TL_TimeTeam}} - Average working time dedicated to team among all respondents.

\cr\strong{\code{TL_YrsInTeam}} - Average team tenure among all respondents.

\cr\strong{\code{TL_NrSeniorRole}} - Total number of seniors on the team
 based on Role "Senior researcher" or "Team leader"

\cr\strong{\code{TL_PercSeniorRole}} - Percentage of seniors based role

\cr\strong{\code{TL_NrPhDRole}} - Total number of Phd students on the team.

\cr\strong{\code{TL_PercPhDRole}} - Percentage of PhD students on the team.

\cr\strong{\code{TL_NrMARole}} - Total number of MA students on the team.

\cr\strong{\code{TL_PercMARole}} - Percentage of MA students on the team.

\cr\strong{\code{TL_NrAdminRole}} - Total number of Administrative staff on the team.

\cr\strong{\code{TL_PercAdminRole}} - Percentage of Administrative staff on the team.

\cr\strong{\code{TL_NrAssistantRole}} - Total number of Research/Lab assistants on the team.

\cr\strong{\code{TL_PercAssistantRole}} - Percentage of Research/Lab assistants on the team.

\cr\strong{\code{TL_NrPostdocRole}} - Total number of Postdocs researchers on the team.

\cr\strong{\code{TL_PercPostdocRole}} - Percentage of Postdocs researchers on the team.

\cr\strong{\code{TL_NrJuniorRole}} - Total number of "junior" researchers on the team:
 either PhDRole or PostdocRole.

\cr\strong{\code{TL_PercJuniorRole}} - Percentage of "junior" researchers on the team:
 either PhDRole or PostdocRole.

\cr\strong{\code{TL_NrNonBibRole}} - Total number of team members not directly contributing to
 publications: Administrative staff, Research/Lab assistants, MA Students OR members younger
 than 24 years (in 2017) and having joined the team after 2014.

\cr\strong{\code{TL_PercNonBibRole}} - Percentage of team members not directly contributing to
 publications. Based on \code{TL_NrNonBibRole}.

\cr\strong{\code{TL_NrSeniorBib}} - OUTDATED. Use updated data in \code{TL_NrSeniorBib_Nov18} !!
 Total number of seniors on the team based upon bibliometric seniority
 defined as having at least 5 publications in Web of Science from 2011 - 2016.

\cr\strong{\code{TL_PercSeniorBib}} - OUTDATED. Use updated data in \code{TL_NrSeniorBib_Nov18} !!
 Percentage of seniors based on bibliometrics. Based upon \code{TL_NrSeniorBib} not updated (Nov 2018) figures!

\cr\strong{\code{TL_NrSeniorExp}} - Total number of seniors on the team based upon experience in the field
 with 10 years or more.

\cr\strong{\code{TL_PercSeniorExp}} - Percentage of seniors based on experience.

\cr\strong{\code{TL_Experience}} - Team level mean years of experience in your field. See also \code{v_83}

\cr\strong{\code{TL_DisciplinHQVar}} - Disciplinary variety. Blau index of variety
 based upon \code{v_5R} discipline of your highest qualification.


\cr\strong{\code{TL_FrqCom}} - Mean frequence of communications across all items \code{v_13-v17} and team members.


\cr\strong{\code{TL_PInfluMean}} - Mean of influence over other team members, across all items \code{v_143-v_145}.


\cr\strong{\code{TL_PInfluDisp}} - Influence disparity over other team members, across all items \code{v_143-v_145}.


\cr\strong{\code{TL_Tclimate}} - Mean team climate across all respondents. Based upon \code{v_151-164}.


\cr\strong{\code{TL_TcliVision}} - Mean team vision across all respondents


\cr\strong{\code{TL_TcliSafety}} - Mean team safety across all respondents


\cr\strong{\code{TL_TcliTask}} - Mean team task across all repondents


\cr\strong{\code{TL_TcliInno}} - Mean team innovation across all respondents


\cr\strong{\code{TL_Leadstyle}} - Mean team leadership style across all respondents based upon \code{v_170-180}.


\cr\strong{\code{TL_LeadIM}} - Mean team leadership inspirational motivation across all respondents


\cr\strong{\code{TL_LeadIC}} - Mean team leadership individualized consideration across all respondents


\cr\strong{\code{TL_LeadIS}} - Mean team leadership intellectual stimulus across all respondents


\cr\strong{\code{TL_LeadII}} - Mean team leadership idealized influence across all respondents


\cr\strong{\code{TL_LeadRExpect}} - Mean score across team members regarding leaders realistic expections of outcome


\cr\strong{\code{TL_LeadRTime}} - Mean score across team members regarding leaders realistic notions of time required


\cr\strong{\code{TL_LeadTrust}} - Mean score across team members regarding leaders capability to foster trust


\cr\strong{\code{TL_Wclimate}} - Mean climate of wider working environment across all respondents. See also \code{v_186-189}


\cr\strong{\code{TL_NrMentors}} - Total number of respondents with mentors. See also \code{v_63}

\cr\strong{\code{TL_PercMentors}} - Percentage of team members with mentor over teamsize.

\cr\strong{\code{TL_NrPermContract}} - Total number of team members with permanent contract. See also \code{v_80}

\cr\strong{\code{TL_PercPermContract}} - Percentage of team members with permanent contract
 over teamsize

\cr\strong{\code{TL_NrTempContract}} - Total number of team members with temporary contract. See also \code{v_80}

\cr\strong{\code{TL_PercTempContract}} - Percentage of team members with temporary
 contract over teamsize

\cr\strong{\code{TL_TimeContracted}} - Mean time contract for among all respondents. See also \code{v_81}

\cr\strong{\code{TL_TimeWorking}} - Mean time actual working hours among all respondents. See also \code{v_82}


\cr\strong{\code{TL_DiffConWork}} - Difference between mean of hours contracted and mean of hours working among all respondents


\cr\strong{\code{TL_TimePub}} - Mean hours dedicated to research/patents across all respondents. See also \code{v_85}.


\cr\strong{\code{TL_QuesPub}} - Mean number of publications among all respondents based on questionnaire info. See also \code{v_130}


\cr\strong{\code{TL_QuesPat}} - Mean number of patents among all respondents based on questionnaire info. See also \code{v_131}


\cr\strong{\code{TL_Fund}} - Mean external funding among all respondents. See also \code{v_84}

\cr\strong{\code{TL_Ethnic}} - Number of team members that belong to ethnic minority group See also \code{v_100R}

\cr\strong{\code{TL_PercEthnic}} - Percentage of team members of ethnic minority group.

\cr\strong{\code{TL_Disability}} - Number of team members with disability See also \code{v_101R}

\cr\strong{\code{TL_PercDisability}} - Percentage of team members with disability.

\cr\strong{\code{TL_Gstereo}} - Mean gender stereotype across all respondents. See also \code{v_195-198}

See also \code{Gstereo} which holds row-wise mean over variables \code{v_195-v_198}.

\cr\strong{\code{TL_CareRespPresent}} - Number of team members with care responsibilities
 in the present.

\cr\strong{\code{TL_CareRespPast}} - Number of team members with care responsibilities
 in the past

\cr\strong{\code{TL_CareResp}} - Number of team members with care responsibilities
 in the present or past.

\cr\strong{\code{TL_PercCareResp}} - Percentage of team members with care responsibilities
 in the present or the past.

\cr\strong{\code{TL_CareDoesAffect}} - Number of team members that think that care responsibilities
 affect or strongly affect their work.

\cr\strong{\code{TL_PercCareDoesAffect}} - Percentage of team members that think that care
 responsibilities affect or strongl affect their work.

\cr\cr\cr\cr
}

\section{Team Contact Survey}{


Some team contact entries have been copied because they are valid at the team level.


\cr\strong{\code{TC_OrgType} - In which type of organisation do you work?}



\cr\strong{\code{TC_NumEmployees} - How many employees does your organisation have?}



\cr\strong{\code{TC_NrWomen, TC_NrMen} - How many women and men are working in your team?}

See also \code{TC_PercWomen, TC_PercMen, TC_GenderBalance}

Reflects answer of team contact/leader on the number of women and men working on the team. Should be seen
in relation to \code{TL_PercRespWomen, TL_PercRespMen, TL_RespGenderBalance} which reflects the gender
balance among respondents.


\cr\strong{\code{TC_FoundingYear} - In which year was the current team leader officially appointed as team leader by your organisation?}



\cr\strong{\code{TC_Colocation} - Do team members have the opportunity to interact face to face?}

\tabular{cl}{
 1 \tab "Most team members share the same physical location (lab, office, building) in walking distance to each other"\cr
 2 \tab "Some team members are within walking distance, others are located further away"\cr
 3 \tab "Most team members are working in different locations; face-to-face meetings require travel arrangements" \cr
}



\cr\strong{\code{TC_GEP} - Does your organisation have a Gender Equality Plan? }



\cr\strong{\code{TC_GenderDim} - Does your research integrate a “gender dimension”?}
}

\section{Performance indicators}{


\cr\strong{\code{FAP1000} - Field Adjusted Productivity}

\code{FAP1000 = FAP*1000} values have been multiplied by 1000 to avoid rounding
errors when converting percentages to real counts.

See also \code{FAP1000} where \code{FAP*1000} values have been multiplied by 1000 to avoid rounding
errors when converting to real counts.

FAP is a measure of research productivity, that is, about how many publications are produced by a
given team. Since productivity varies between disciplines, the indicator normalizes the number
of publications to the average productivity of a senior researcher within a given field. Field
Adjusted Productivity is thus an abstract quantity in the sense that it measures productivity not in
direct publication counts, but via the average number of papers published by a senior researcher.
This might be relatively high for researchers working in engineering disciplines and lower for
seniors working in social sciences or humanities.

The unit of FAP is therefore "average productivity of one senior reseacher". A FAP of 1 means that the
given group has the productivity of one senior researcher in its field. A FAP of 5 means that a given
team produces as many papers as one would expect of a group comprising 5 senior researchers (within
the given field). This is independent of the actual team size and actual number of senior researchers
a given team actually has. A very productive team would be a team of 2, one senior and one PhD with a
FAP score of 4 - meaning they produce as many papers in their field as you would expect from a team made
up of 4 senior researchers.

The FAP scores have been benchmarked according to the average research output of all nordic countries.
Data was collected over a 4 year period, which means a FAP score of 1 reflects the research productivity
of a senior researcher over 4 years. This might be 20 papers for medical scholars and 4 papers for
sociologists, both having a corresponding FAP score of 1.

In the GEDII project, publication data was collected over a period of 8 years. Although we can expect
that this produces up to 40 papers for medical scholars (to stick with the previous example) and
8 papers for sociologist, the resulting FAP score for both is "2". This is to say that the FAP score
is \emph{not} normalized over the time period the corresponding publications were collected. This is
important when interpreting the coefficients of potential regressions: the time period over which
a group gains/looses the productivity of a senior has always to be taken into account.



\cr\strong{\code{PMM1000} - Percentile Model}

\code{PMM1000 = PMM*1000} values have been multiplied by 1000 to avoid rounding
errors when converting percentages to real counts.

Articles are rated based upon their citations and then assigned to point-categories, such that an article
in the top 1\% = 100 points, top 5\% = 20 points, top 10\% = 10 points, top 25\% = 4 points, top 50\% = 2
points and the rest 1 point. The percentile model is field adjusted. The higher the PM score, the more
likely is that the output of a team belongs to the top research groups within a ield. For instance, if a
team’s publicatons are mainly amongst the top 1\% of all cited publicatons within their area of research,
they would achieve one of the highest PM scores, while teams with few citatons would be on the bottom end
of the PM score.



\cr\strong{Index.6 - Gender Diversity Index score}

The Gender Diversity Index score of the team. Seven grounds of diversity are included: age, educational
level, care responsibilites, marital status, type of contract, seniority and team tenure (years of
experience in the team). The Gender Diversity Index is a composite indicator which combines data on those
seven grounds into one fgure. It is bound between 0 and 1, and measures both parity in representaton in
the most desirable categories (e.g. senior roles) or more inclusive categories (e.g. care responsibilites),
as well as equal chances for women and men to access these categories (atriton) for each of the seven
grounds. In other words, women and men should be equally represented in the more desirable or inclusive
categories, and the 'pipeline' there should not be leaking.


\cr\strong{Gender Diversity Index - Individual Pillars}

The scores for the individual pillars that comprise the GDI are included in the dataset: Seniority,
Tenure, CareCurrent, Contract, Education, Marital Status, and Age. Three variables are available for
each pillar: X_attrition, X_blauH, and X_score.

\itemize{
 \item{Seniority_attrition: the attrition score for this pillar}
 \item{Seniority_blauH: the blau index (representation) for this pillar}
 \item{Seniority_score: individual score for this pillar}
 \item{Tenure_attrition: the attrition score for this pillar}
 \item{Tenure_blauH: the blau index (representation) for this pillar}
 \item{Tenure_score: individual score for this pillar}
 \item{CareCurrent_attrition: the attrition score for this pillar}
 \item{CareCurrent_blauH: the blau index (representation) for this pillar}
 \item{CareCurrent_score: individual score for this pillar}
 \item{Contract_attrition: the attrition score for this pillar}
 \item{Contract_blauH: the blau index (representation) for this pillar}
 \item{Contract_score: individual score for this pillar}
 \item{Education_attrition: the attrition score for this pillar}
 \item{Education_blauH: the blau index (representation) for this pillar}
 \item{Education_score: individual score for this pillar}
 \item{Marital_attrition: the attrition score for this pillar}
 \item{Marital_blauH: the blau index (representation) for this pillar}
 \item{Marital_score: individual score for this pillar}
 \item{AgeAv_attrition: the attrition score for this pillar}
 \item{AgeAv_blauH: the blau index (representation) for this pillar}
 \item{AgeAv_score: individual score for this pillar}
}

\cr\cr
}

\section{November 2018 Changes}{


Several changes where introduced during November 2018. This includes a correction of performance data
for several groups as well as variables that have been aggregated or transformed based upon existing
variables. All these data refers to the team level but is included into the ccs dataset as well.

\cr\strong{\code{FAP8Y1000_Nov18} - Field Adjusted Productivity, 8 years}

Productivity score based upon 8 years of retrieval of publications, updated for some groups.

\cr\strong{\code{FAP5Y_Nov18} - Field Adjusted Productivity, 5 years}

Productivity score based upon 5 year retrieval of publications. Years included are 2012-2016.


\cr\strong{\code{FAP5Y1000_Nov18} - Field Adjusted Productivity, 5 years x 1000}

\code{FAP5Y_Nov18} multiplied by 1000.


\cr\strong{\code{FAP5Y1000xNrSeniorBib_Nov18} - FAP divided by NrSeniorsBib}

Productivity \code{FAP5Y1000_Nov18} divided by \code{NrSeniorBib_Nov18}.


\cr\strong{\code{PMM8Y1000_Nov18} - Percentile Model, 8 years}

Percentile Model score based upon 8 years of retrieval of publications.

\cr\strong{\code{PMM5Y_Nov18} - Percentile Model, 5 years}

Percentile model based upon 5 years of retrievel of publications. Years included are 2012-2016.


\cr\strong{\code{PMM5Y1000_Nov18 } - Percentile Model, 5 years x 1000}

Percentile Model \code{PMM5Y_Nov18 } multiplied by 1000.


\cr\strong{\code{PMM5Y1000xNrSeniorBib_Nov18} - Percentile Model divided by NrSeniorsBib}

Percentile Model \code{PMM1000_Nov18} divided by \code{NrSeniorBib_Nov18}.


\cr\strong{\code{TeamType_Nov18} - Team type}

Recoded variable based upon \code{NrSeniorBib}:

\tabular{cl}{
 1 - \tab "NrSeniorBib == 1"\cr
 2 - \tab "NrSeniorBib >= 2 and NrSeniorBib <= 4"\cr
 3 - \tab "NrSeniorBib >= 5" \cr
}


\cr\strong{\code{ColocationBib_Nov18} - Colocation based on bibliometrics}

Bibliometrics based colocation. All authors have same address or not. See also \code{TC_Colocation}
which is based upon questionnaire Team Contact information.

\tabular{cl}{
 1 - \tab "Authors have same address; colocated"\cr
 2 - \tab "Authors have different addresses; distributed"\cr
}


\cr\strong{\code{Inward_Nov18} - Co-author pattern}

Percentage of fractions from the group authors in relation to fractions from co-authors outside the group.


\cr\strong{\code{InwardNorm_Nov18} - Co-author pattern (field normalized)}

Normalized mean "Inward" score based upon field specific factors.


\cr\strong{\code{InwardNormMedian_Jan19} - Co-author pattern (field normalized)}

Normalized median "Inward" score based upon field specific factors.


\cr\strong{\code{OrgTypeR_Nov18} - Organisation type}

Recoded organisation type. See also \code{TC_OrgType}

\tabular{cl}{
 1 - \tab "University. TC_OrgType == 1"\cr
 2 - \tab "RPO. TC_OrgType == 2"\cr
 3 - \tab "Other. TC_OrgType == 3 | 6" \cr
}


\cr\strong{\code{TL_NrSeniorBib_Nov18} - Number of seniors (bibliometrics)}

Seniors are assigned based upon bibliometric information based upon the following algorithm:
1) at least 2.75 points in Sum (column G=PM5) and at least 3 yrs of publishing activity. The score of
"2.75" has been derived from testing the level of TOP25 \% of Swedish researchers (borderline).
Time window of publication is based upon 5 years (2012-2016).


\cr\strong{\code{TL_PercSeniorBib_Nov18} - Percentage of seniors (bibliometrics)}

Updated percentage of seniors derived from bibliometrics.


\cr\strong{\code{Field_Nov18} - Scientific fields}

Based upon bibliometric analysis.

\tabular{cl}{
 1 - \tab "Applied"\cr
 2 - \tab "EcSoc"\cr
 3 - \tab "Health" \cr
 4 - \tab "Natural" \cr
}


\cr\strong{\code{Applied_Nov18} - ??}

Based on bibliometric data, most frequent value in the bibliometrics per group, all groups have
several macro-fields but the applied is the largest. ?? \emph{still not clear what entries mean.}

\cr\strong{\code{CountryBib_Nov18} - ??}

National code is based on performance of country in relation to EU average (bibliometrics).
Based on country performance in EC 2013 Research and Innovation Performance in EU member states.
?? \emph{still not clear what entries mean.}

\cr\strong{\code{SubjectFieldDiv_Nov18} - ??}
}

